merge_document — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

# merge_document

Wizard to merge documents with a list of objects.

This wizard is triggered thru an entry in the main menu.

class `camelot.view.wizard.merge_document.` `MergeDocumentWizard`(parent=None, selection_getter=None)

  This wizard lets the user select a template file, it then merges that template will all the selected rows in a table

class `camelot.view.wizard.merge_document.` `MergePage`(parent, selection_getter)

  Wait until merge is complete

class `camelot.view.wizard.merge_document.` `SelectTemplatePage`(parent=None)

  Page to select the template to merge

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

Comments
blog comments powered by Disqus